/**
 * EasyBeans
 * Copyright 2013 Peergreen S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JPersistenceUnitInfo.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.persistence.util;

import java.lang.instrument.ClassFileTransformer;
import java.lang.instrument.IllegalClassFormatException;
import java.lang.instrument.Instrumentation;
import java.security.ProtectionDomain;

import javax.persistence.spi.ClassTransformer;

/**
 * Wraps a JPA ClassTransformer into a ClassFileTransformer.
 * @author Florent Benoit
 */
public class ClassTransformerAdapter implements ClassFileTransformer {

    /**
     * JPA class transformer.
     */
    private final ClassTransformer classTransformer;

    /**
     * Build an adapter on the JPA class transformer.
     * @param classTransformer the JPA transformer
     */
    public ClassTransformerAdapter(ClassTransformer classTransformer) {
        this.classTransformer = classTransformer;
    }

    /**
     * Transforms a class
     * @param loader the defining loader of the class to be transformed, may be
     * <code>null</code> if the bootstrap loader
     * @param className the name of the class in the internal form of fully
     * qualified class and interface names as defined in <i>The Java Virtual
     * Machine Specification</i>. For example, <code>"java/util/List"</code>.
     * @param classBeingRedefined if this is triggered by a redefine or
     * retransform, the class being redefined or retransformed; if this is a
     * class load, <code>null</code>
     * @param protectionDomain the protection domain of the class being defined
     * or redefined
     * @param classfileBuffer the input byte buffer in class file format - must
     * not be modified
     * @throws IllegalClassFormatException if the input does not represent a
     * well-formed class file
     * @return a well-formed class file buffer (the result of the transform), or
     * <code>null</code> if no transform is performed.
     * @see Instrumentation#redefineClasses
     */
    @Override
    public byte[] transform(ClassLoader loader, String className, Class<?> classBeingRedefined,
            ProtectionDomain protectionDomain, byte[] classfileBuffer) throws IllegalClassFormatException {
        return classTransformer.transform(loader, className, classBeingRedefined, protectionDomain, classfileBuffer);
    }

}
